==> metasploit-4.6.2.txz: usr/local/share/metasploit/README.md <==

Metasploit [![Build Status](https://travis-ci.org/rapid7/metasploit-framework.png)](https://travis-ci.org/rapid7/metasploit-framework) [![Code Climate](https://codeclimate.com/badge.png)](https://codeclimate.com/github/rapid7/metasploit-framework)
==
The Metasploit Framework is released under a BSD-style license. See
COPYING for more details.

The latest version of this software is available from http://metasploit.com/

Bug tracking and development information can be found at:
 https://dev.metasploit.com/redmine/projects/framework/

The public GitHub source repository can be found at:
 https://github.com/rapid7/metasploit-framework

Questions and suggestions can be sent to:
 msfdev(at)metasploit.com

The framework mailing list is the place to discuss features and ask for help.
To subscribe, visit the following web page:
 https://mail.metasploit.com/mailman/listinfo/framework

The mailing list archives are available from:
 https://mail.metasploit.com/pipermail/framework/

Installing
--
Generally, you should use the installer which contains all dependencies
and will get you up and running with a few clicks. See the [Dev
Environment Setup][wiki-devenv] if you'd like to deal with dependencies
on your own.

Using Metasploit
--
Metasploit can do all sorts of things. The first thing you'll want to do
is start `msfconsole`, but after that, you'll probably be best served by
reading some of the great tutorials online:

  * [Metasploit Unleashed][unleashed]
  * [The official Metasploit wiki on Github][wiki-start]

Contributing
--
See the [Dev Environment Setup][wiki-devenv] guide on GitHub which will
walk you through the whole process starting from installing all the
dependencies, to cloning the repository, and finally to submitting a
pull request. For slightly more info, see
[Contributing](https://github.com/rapid7/metasploit-framework/blob/master/CONTRIBUTING.md).


[wiki-devenv]: https://github.com/rapid7/metasploit-framework/wiki/Metasploit-Development-Environment "Metasploit Development Environment Setup"
[wiki-start]: https://github.com/rapid7/metasploit-framework/wiki/ "Metasploit Wiki"
[wiki-usage]: https://github.com/rapid7/metasploit-framework/wiki/Using-Metasploit "Using Metasploit"
[unleashed]: http://www.offensive-security.com/metasploit-unleashed/ "Metasploit Unleashed"

==> metasploit-4.9.3_1.txz: usr/local/share/metasploit/README.md <==

Metasploit [![Build Status](https://travis-ci.org/rapid7/metasploit-framework.png)](https://travis-ci.org/rapid7/metasploit-framework) [![Code Climate](https://codeclimate.com/badge.png)](https://codeclimate.com/github/rapid7/metasploit-framework)
==
The Metasploit Framework is released under a BSD-style license. See
COPYING for more details.

The latest version of this software is available from http://metasploit.com/

Bug tracking and development information can be found at:
 https://dev.metasploit.com/redmine/projects/framework/

The public GitHub source repository can be found at:
 https://github.com/rapid7/metasploit-framework

Questions and suggestions can be sent to:
 msfdev(at)metasploit.com

The framework mailing list is the place to discuss features and ask for help.
To subscribe, visit the following web page:
 https://mail.metasploit.com/mailman/listinfo/framework

The mailing list archives are available from:
 https://mail.metasploit.com/pipermail/framework/

Installing
--

Generally, you should use [the free installer](https://www.metasploit.com/download)
which contains all dependencies and will get you up and running with a
few clicks. See the [Dev Environment Setup](http://r-7.co/MSF-DEV) if
you'd like to deal with dependencies on your own.

Using Metasploit
--
Metasploit can do all sorts of things. The first thing you'll want to do
is start `msfconsole`, but after that, you'll probably be best served by
reading some of the great tutorials online:

  * [Metasploit Unleashed][unleashed]
  * [The official Metasploit wiki on Github][wiki-start]

Contributing
--
See the [Dev Environment Setup][wiki-devenv] guide on GitHub which will
walk you through the whole process starting from installing all the
dependencies, to cloning the repository, and finally to submitting a
pull request. For slightly more info, see
[Contributing](https://github.com/rapid7/metasploit-framework/blob/master/CONTRIBUTING.md).


[wiki-devenv]: https://github.com/rapid7/metasploit-framework/wiki/Setting-Up-a-Metasploit-Development-Environment "Metasploit Development Environment Setup"
[wiki-start]: https://github.com/rapid7/metasploit-framework/wiki/ "Metasploit Wiki"
[wiki-usage]: https://github.com/rapid7/metasploit-framework/wiki/Using-Metasploit "Using Metasploit"
[unleashed]: http://www.offensive-security.com/metasploit-unleashed/ "Metasploit Unleashed"
